package com.livelike.flickersearchlibrary.di

import com.livelike.flickersearchlibrary.api.FlickrApi
import com.livelike.flickersearchlibrary.api.utils.BASE_URL
import com.livelike.flickersearchlibrary.service.FlickrService
import com.livelike.flickersearchlibrary.service.logic.FlickrServiceLogic
import com.squareup.moshi.Moshi
import com.squareup.moshi.kotlin.reflect.KotlinJsonAdapterFactory
import org.koin.core.context.startKoin
import org.koin.dsl.module
import retrofit2.Retrofit
import retrofit2.converter.moshi.MoshiConverterFactory

/**
 * Defines dependencies required by Flickr service features.
 */
internal object Dependencies {

    private val flickrModule = module {

        single<FlickrApi> {
            val moshi = Moshi.Builder()
                .add(KotlinJsonAdapterFactory())
                .build()
            val retrofit = Retrofit.Builder()
                .baseUrl(BASE_URL)
                .addConverterFactory(MoshiConverterFactory.create(moshi))
                .build()
            retrofit.create(FlickrApi::class.java)
        }

        single<FlickrService> { FlickrServiceLogic(get()) }

    }

    /**
     * Initializes all dependencies needed for Flick service features.
     */
    internal fun init() {
        startKoin {
            modules(flickrModule)
        }
    }
}