package com.livelike.flickersearchlibrary.service.logic

import android.util.Log
import com.livelike.flickersearchlibrary.api.FlickrApi
import com.livelike.flickersearchlibrary.api.model.Photo
import com.livelike.flickersearchlibrary.service.FlickrService

/**
 * Implementation of [FlickrService].
 */
internal class FlickrServiceLogic(private val api: FlickrApi) : FlickrService {

    private val cachedPhotos = mutableListOf<Photo>()

    override suspend fun search(searchQuery: String): List<Photo> {
        val response = api.search(searchQuery)
        if (response.isSuccessful) {
            response.body()?.let {
                cachedPhotos.clear()
                cachedPhotos.addAll(it.photosPage.photos)
            }
        } else {
            Log.d(
                "FlickrService",
                "Flickr API responded with error: " + response.errorBody().toString()
            )
        }

        return cachedPhotos
    }
}